#!/usr/bin/python
# @file    obexparser
# @author  David Zemon
#
# Created with: PyCharm

import io
import os
import re
from html.parser import HTMLParser


class ObexParser(HTMLParser):
    WHITESPACE_PATTERN = re.compile('\s*')

    def __init__(self, output):
        """
        :param output: Output file
        :type output io.TextIOWrapper
        """
        super().__init__()
        self._output = output
        self._inCell = False
        self._inLink = False

    def feed(self, data):
        self._output.write('"Link",')
        super().feed(data)

    def handle_endtag(self, tag):
        if tag == 'tr':
            self._output.write('\n')
        elif tag == 'td':
            self._inCell = False
            self._output.write(',')

    def handle_data(self, data):
        """
        :param data:
        :type data str
        """
        if self._inCell:
            content = ' '.join(data.strip().split())
            if content:
                self._output.write('"%s"' % content)

    def handle_starttag(self, tag, attrs):
        if tag == 'td':
            self._inCell = True
        elif tag == 'a' and self._inCell:
            attribute_dict = dict(attrs)
            self._output.write('"%s",' % attribute_dict['href'])

    def error(self, message):
        raise Exception(message)


def parse():
    with open(os.path.expanduser('~/Desktop/obex.html'), 'r') as html_file:
        html_content = html_file.read()

    with open(os.path.expanduser('~/Desktop/obex_table.csv'), 'w') as csv_file:
        parser = ObexParser(csv_file)
        parser.feed(html_content)


parse()
